# Pretrained scArches Models 

| Task | model link | Description | 
| ----------- | ----------- | ----------- |
| Pancreas | [Download Link](https://google.com/)  | Trained scNet on 5 pancreas batches |
| Mouse Brain | [Download Link](https://google.com/)  | Trained scNet on Mouse Brain dataset |
| Human Cell Landscape (HCL) | [Download Link](https://google.com/)  | Trained scNet on HCL |
| Tabula Muris Senis | [Download Link](https://google.com/)  | Trained scNet on Senis with surgery on Muris |
| Tabula Muris Senis + Mouse Cell Atlas | [Download Link](https://google.com/)  | Trained scNet on Muris Senis with surgery on MCA |
| Human Cell Landscape (HCL) + Mouse Cell Atlas | [Download Link](https://google.com/)  | Trained scNet on HCL with surgery on MCA |
